@@ -1038,22 +1038,28 @@ gnome_print_ps2_set_font_real (GnomePrintPs2 *ps2, const GnomeFont *gnome_font,
 
 	face = gnome_font->face;
 
+	/*
+	 * In ps2->selected_font we already have the font with which the 
+	 * previous glyph (if one was there) is printed. Checks whether the 
+	 * gnome_font->face->psname and subfont_number combination 
+	 * (encodedstring) with which current glyph is to be printed matches 
+	 * the previous one. If that's the case all we need to check is there's
+	 * a match in the print font size too. If these matches we will just
+	 * return without doing anything.
+	 */
+
 	if (subfont_flag) {
-		guchar *current_str;
                 if (subfont_number == 0)
-                        encodedstring = g_strdup_printf ("(GnomeUni-%s) cvn FF %g",gnome_font->face->psname, gnome_font_get_size (gnome_font));
+                        encodedstring = g_strdup_printf ("GnomeUni-%s",gnome_font->face->psname);
                 else
-                        encodedstring = g_strdup_printf ("(GnomeUni-%s_%03d) cvn FF %g",gnome_font->face->psname, subfont_number, gnome_font_get_size (gnome_font));
+                        encodedstring = g_strdup_printf ("GnomeUni-%s_%03d",gnome_font->face->psname, subfont_number);
 
 		if (ps2->selected_font &&
 		    ps2->selected_font->pso &&
 		    ps2->selected_font->pso->encodedname) {
 
-			current_str = g_strdup_printf ("(%s) cvn FF %g", ps2->selected_font->pso->encodedname, ps2->selected_font->currentsize);
-
-			if (!strcmp (encodedstring, current_str)) {
+			if (!strcmp (encodedstring, ps2->selected_font->pso->encodedname) && (gnome_font_get_size (gnome_font) == ps2->selected_font->currentsize)) {
 				g_free (encodedstring);
-				g_free (current_str);
 				return 0;
 			}
 		}
@@ -1068,15 +1074,18 @@ gnome_print_ps2_set_font_real (GnomePrintPs2 *ps2, const GnomeFont *gnome_font,
 
 	face = gnome_font_get_face (gnome_font);
 
+	/*
+	 * Check whether encodedstring we created before is already encountered
+	 * and stored in ps2->fonts. If already encountered no need to create
+	 * a new font.
+	 */
+
 	for (font = ps2->fonts; font != NULL; font = font->next) {
 		if (subfont_flag) {
-			gchar *newencodedstring = g_strdup_printf ("(%s) cvn FF %g",
-				font->pso->encodedname, font->currentsize);
-			if  (!strcmp (newencodedstring, encodedstring)) {
-				g_free (newencodedstring);
+			if  (!strcmp (font->pso->encodedname, encodedstring)) {
+				g_free (encodedstring);
 				break;
 			}
-			g_free (newencodedstring);
 		} else if (font->face == face)
 			break;
 	}
@@ -1089,6 +1098,13 @@ gnome_print_ps2_set_font_real (GnomePrintPs2 *ps2, const GnomeFont *gnome_font,
 			instance = clone->instance + 1;
 		}
 	}
+
+	/*
+	 * The font with which we need to print the new glyph is not in 
+	 * ps2->fonts font list and we need to create a new one and append
+	 * it to the list.
+	 */
+
 	if (!font) {
 		/* No entry, so create one */
 		gnome_font_face_ref (face);
@@ -1113,6 +1129,10 @@ gnome_print_ps2_set_font_real (GnomePrintPs2 *ps2, const GnomeFont *gnome_font,
 		ps2->pages->usedfonts = g_slist_prepend (ps2->pages->usedfonts, font);
 	}
 
+	/*
+	 * Output the font/size etc. for printing.
+	 */
+
 	ret += gnome_print_ps2_fprintf (ps2, "(%s) cvn FF ", 
 					font->pso->encodedname);
 	ret += gnome_print_ps2_print_double (ps2, "%g", 
